@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.174.2.1 2005/03/27 18:56:09 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.174.2.3 2005/05/22 22:47:35 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -549,7 +549,7 @@ load_video_out_driver (BaconVideoWidget *bvw, gboolean null_out)
 	x11_visual_t vis;
 	const char *video_driver_id;
 	xine_video_port_t *vo_driver;
-	static char *drivers[] = { "xxmc", "xv", "xshm" };
+	static char *drivers[] = { "xv", "xshm" };
 	guint i;
 
 	if (null_out != FALSE)
@@ -3057,6 +3057,7 @@ bacon_video_widget_set_zoom (BaconVideoWidget *bvw, int zoom)
 	g_return_if_fail (bvw != NULL);
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
 	g_return_if_fail (bvw->priv->xine != NULL);
+	g_return_if_fail (zoom >= 0 && zoom <= 400);
 
 	xine_set_param (bvw->priv->stream,
 			XINE_PARAM_VO_ZOOM_X, zoom);
