@@ -84,6 +84,9 @@
 
 #define ZOOM_IN_OFFSET 1
 #define ZOOM_OUT_OFFSET -1
+#define ZOOM_UPPER 200
+#define ZOOM_RESET 100
+#define ZOOM_LOWER 10
 
 #define FULLSCREEN_POPUP_TIMEOUT 5 * 1000
 
@@ -828,19 +831,60 @@ totem_action_seek_relative (Totem *totem, int off_sec)
 	}
 }
 
+static void
+totem_action_zoom (Totem *totem, int zoom)
+{
+	GtkWidget *item;
+
+	if (zoom < ZOOM_LOWER || zoom > ZOOM_UPPER)
+		return;
+
+	bacon_video_widget_set_zoom (totem->bvw, zoom);
+
+	if (zoom == ZOOM_UPPER) {
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_in_menu_item");
+		gtk_widget_set_sensitive (item, FALSE);
+	} else if (zoom == ZOOM_LOWER) {
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_out_menu_item");
+		gtk_widget_set_sensitive (item, FALSE);
+	} else if (zoom == ZOOM_RESET) {
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_reset_menu_item");
+		gtk_widget_set_sensitive (item, FALSE);
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_in_menu_item");
+		gtk_widget_set_sensitive (item, TRUE);
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_out_menu_item");
+		gtk_widget_set_sensitive (item, TRUE);
+	} else {
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_in_menu_item");
+		gtk_widget_set_sensitive (item, TRUE);
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_out_menu_item");
+		gtk_widget_set_sensitive (item, TRUE);
+		item = glade_xml_get_widget
+			(totem->xml, "tmw_zoom_reset_menu_item");
+		gtk_widget_set_sensitive (item, TRUE);
+	}
+}
+
 static void
 totem_action_zoom_relative (Totem *totem, int off_pct)
 {
 	int zoom;
 
 	zoom = bacon_video_widget_get_zoom (totem->bvw);
-	bacon_video_widget_set_zoom (totem->bvw, zoom + off_pct);
+	totem_action_zoom (totem, zoom + off_pct);
 }
 
 static void
 totem_action_zoom_reset (Totem *totem)
 {
-	bacon_video_widget_set_zoom (totem->bvw, 100);
+	totem_action_zoom (totem, 100);
 }
 
 void
@@ -2234,8 +2278,10 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 		break;
 	}
 
-	if (handled != FALSE)
+	if (handled != FALSE &&
+			gtk_window_is_active (GTK_WINDOW (totem->win))) {
 		on_video_motion_notify_event (NULL, NULL, totem);
+	}
 }
 
 #ifdef HAVE_REMOTE
@@ -2338,10 +2384,12 @@ playlist_shuffle_toggle_cb (TotemPlaylist *playlist, gboolean shuffle, Totem *to
 static void
 update_fullscreen_size (Totem *totem)
 {
-	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
+	GdkScreen *screen;
+
+	screen = gtk_window_get_screen (GTK_WINDOW (totem->win));
+	gdk_screen_get_monitor_geometry (screen,
 			gdk_screen_get_monitor_at_window
-			(gdk_screen_get_default (),
-			 totem->win->window),
+			(screen, totem->win->window),
 			&totem->fullscreen_rect);
 }
 
@@ -2357,6 +2405,8 @@ move_popups (Totem *totem)
 	int control_width, control_height;
 	int exit_width, exit_height;
 
+	update_fullscreen_size (totem);
+
 	gtk_window_get_size (GTK_WINDOW (totem->control_popup),
 			&control_width, &control_height);
 	gtk_window_get_size (GTK_WINDOW (totem->exit_popup),
@@ -2374,23 +2424,20 @@ move_popups (Totem *totem)
 				totem->fullscreen_rect.y);
 		gtk_window_move (GTK_WINDOW (totem->control_popup),
 				totem->fullscreen_rect.width - control_width,
-				totem->fullscreen_rect.height
-				- control_height);
+				totem->fullscreen_rect.height + totem->fullscreen_rect.y - control_height);
 	} else {
 		gtk_window_move (GTK_WINDOW (totem->exit_popup),
-				totem->fullscreen_rect.width - exit_width,
+				totem->fullscreen_rect.width + totem->fullscreen_rect.x - exit_width,
 				totem->fullscreen_rect.y);
 		gtk_window_move (GTK_WINDOW (totem->control_popup),
 				totem->fullscreen_rect.x,
-				totem->fullscreen_rect.height
-				- control_height);
+				totem->fullscreen_rect.height + totem->fullscreen_rect.y - control_height);
 	}
 }
 
 static void
 size_changed_cb (GdkScreen *screen, Totem *totem)
 {
-	update_fullscreen_size (totem);
 	move_popups (totem);
 }
 
